@@ -20,7 +20,8 @@
 	TEST(ct_cursor) \
 	TEST(ct_con_props) \
 	TEST(ct_cmd_props) \
-	TEST(cs_convert)
+	TEST(cs_convert) \
+	TEST(cs_dt_info)
 
 /* forward declare all tests */
 #undef TEST
@@ -545,9 +546,43 @@ static void
 test_cs_convert(void)
 {
 	CS_INT retlen;
-	char outbuf[32];
+	char outbuf[64];
+	typedef struct format_test
+	{
+		CS_INT datatype;
+		CS_INT format;
+		bool success;
+	} format_test;
+
+	static const format_test format_tests[] = {
+		{CS_CHAR_TYPE, CS_FMT_UNUSED, true},
+		{CS_CHAR_TYPE, CS_FMT_NULLTERM, true},
+		{CS_CHAR_TYPE, CS_FMT_PADNULL, true},
+		{CS_CHAR_TYPE, CS_FMT_PADBLANK, true},
+		{CS_CHAR_TYPE, CS_FMT_JUSTIFY_RT, false},
+		{CS_CHAR_TYPE, CS_FMT_STRIPBLANKS, false},
+#if 0
+		/* supported by Sybase, not FreeTDS currently */
+		{CS_CHAR_TYPE, CS_FMT_SAFESTR, true},
+		{CS_CHAR_TYPE, CS_FMT_SUBS_ILL_CHAR, true},
+#endif
+
+		{CS_BINARY_TYPE, CS_FMT_UNUSED, true},
+		{CS_BINARY_TYPE, CS_FMT_NULLTERM, false},
+		{CS_BINARY_TYPE, CS_FMT_PADNULL, true},
+		{CS_BINARY_TYPE, CS_FMT_PADBLANK, false},
+		{CS_BINARY_TYPE, CS_FMT_JUSTIFY_RT, false},
+		{CS_BINARY_TYPE, CS_FMT_STRIPBLANKS, false},
+		{CS_BINARY_TYPE, CS_FMT_SAFESTR, false},
+		{CS_BINARY_TYPE, CS_FMT_SUBS_ILL_CHAR, false},
+
+		{-1, -1, false},
+	};
+	const format_test *p_format_test;
+	CS_NUMERIC num = { 1, 1, {0, 1,} };
 
 	CS_DATAFMT destfmt, srcfmt;
+
 	memset(&srcfmt, 0, sizeof(srcfmt));
 	memset(&destfmt, 0, sizeof(destfmt));
 
@@ -584,4 +619,97 @@ test_cs_convert(void)
 	check_last_message(CTMSG_CSLIB, 0x2010112,
 			   "An illegal value of -1 was placed in the maxlength field of the CS_DATAFMT structure");
 	destfmt.maxlength = 0;
+
+	/* invalid formats */
+	for (p_format_test = format_tests; p_format_test->datatype >= 0; ++p_format_test) {
+		destfmt.datatype = p_format_test->datatype;
+		destfmt.format = p_format_test->format;
+		destfmt.maxlength = 20;
+		srcfmt.maxlength = 4;
+		if (p_format_test->success) {
+			check_call(cs_convert, (ctx, &srcfmt, "3234", &destfmt, outbuf, &retlen));
+		} else {
+			check_fail(cs_convert, (ctx, &srcfmt, "3234", &destfmt, outbuf, &retlen));
+			check_last_message(CTMSG_CSLIB, 0x2010112, "was placed in the format field of the CS_DATAFMT structure");
+		}
+	}
+	destfmt.format = CS_FMT_UNUSED;
+	destfmt.maxlength = 0;
+	srcfmt.maxlength = 0;
+
+	/* test invalid scale/precision for numeric */
+	destfmt.datatype = CS_NUMERIC_TYPE;
+	destfmt.precision = 1;
+	check_call(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+
+	destfmt.precision = 0;
+	check_fail(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+	check_last_message(CTMSG_CSLIB, 0x2010112, "was placed in the precision field of the CS_DATAFMT structure");
+
+	destfmt.precision = 78;
+	check_fail(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+	check_last_message(CTMSG_CSLIB, 0x2010112, "was placed in the precision field of the CS_DATAFMT structure");
+
+	destfmt.precision = 30;
+	destfmt.scale = -1;
+	check_fail(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+	check_last_message(CTMSG_CSLIB, 0x2010112, "was placed in the scale field of the CS_DATAFMT structure");
+
+	destfmt.scale = 0;
+	check_call(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+
+	destfmt.scale = 30;
+	check_call(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+
+	destfmt.scale = 31;
+	check_fail(cs_convert, (ctx, &srcfmt, &num, &destfmt, outbuf, &retlen));
+	check_last_message(CTMSG_CSLIB, 0x2010112, "was placed in the scale field of the CS_DATAFMT structure");
+}
+
+static void
+test_cs_dt_info(void)
+{
+	CS_LOCALE *locale;
+	CS_INT i_value = CS_DATES_SHORT;
+	CS_INT len;
+
+	check_call(cs_loc_alloc, (ctx, &locale));
+
+	check_call(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, sizeof(i_value), NULL));
+
+	/* no context  */
+	check_fail(cs_dt_info, (NULL, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, sizeof(i_value), NULL));
+	check_last_message(CTMSG_NONE, 0, NULL);
+
+	/* wrong action */
+	check_fail(cs_dt_info, (ctx, 1000, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, sizeof(i_value), NULL));
+	check_last_message(CTMSG_CSLIB, 0x02010106, " 1000 was given for parameter action");
+
+	/* wrong type, set */
+	check_fail(cs_dt_info, (ctx, CS_SET, locale, 1000, CS_UNUSED, &i_value, sizeof(i_value), NULL));
+	check_last_message(CTMSG_CSLIB, 0x02010106, " 1000 was given for parameter type");
+
+	/* wrong type, get */
+	len = sizeof(i_value);
+	check_fail(cs_dt_info, (ctx, CS_GET, locale, 1000, CS_UNUSED, &i_value, sizeof(i_value), &len));
+	check_last_message(CTMSG_CSLIB, 0x02010106, " 1000 was given for parameter type");
+
+	/* wrong length  */
+	check_fail(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, -4, NULL));
+	check_last_message(CTMSG_CSLIB, 0x02010106, " -4 was given for parameter buflen");
+
+	/* CS_NULLTERM as length is not accepted */
+	check_fail(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, CS_NULLTERM, NULL));
+	check_last_message(CTMSG_CSLIB, 0x02010106, " -9 was given for parameter buflen");
+
+	/* any other length seems accepted */
+	check_call(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, 0, NULL));
+	check_call(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, 1, NULL));
+	check_call(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, 100, NULL));
+
+	/* invalid values are also accepted */
+	i_value = -10000;
+	check_call(cs_dt_info, (ctx, CS_SET, locale, CS_DT_CONVFMT, CS_UNUSED, &i_value, sizeof(i_value), NULL));
+
+	check_call(cs_loc_drop, (ctx, locale));
 }
